---------------
ncempy examples
---------------

Directory for examples within the NCEMpy project.

EDSTomo
-------

* data/L2083-K-4-1/ConvertBrukerToEMD/ConvertBrukerToEMD.ipynb
    Example to convert a tomographic tilt series of Bruker bcf files into the NCEMpy EMD format.  This example has a dependency on the hyperspy package.


* data/L2083-K-4-1/ReconstructEDSTomo/ReconstructEDSTomo.ipynb
    Example to reconstruct an EDS tomographic tilt series using the EDSTomo module and GENFIRE.
